@@ -337,6 +337,12 @@ void _arb_poly_product_roots(arb_ptr poly, arb_srcptr xs, slong n, slong prec);
 
 void arb_poly_product_roots(arb_poly_t poly, arb_srcptr xs, slong n, slong prec);
 
+void _arb_poly_product_roots_complex(arb_ptr poly, arb_srcptr r, slong rn,
+    acb_srcptr c, slong cn, slong prec);
+
+void arb_poly_product_roots_complex(arb_poly_t poly,
+        arb_srcptr r, slong rn, acb_srcptr c, slong cn, slong prec);
+
 arb_ptr * _arb_poly_tree_alloc(slong len);
 
 void _arb_poly_tree_free(arb_ptr * tree, slong len);
@@ -506,6 +512,10 @@ void _arb_poly_binomial_transform(arb_ptr b, arb_srcptr a, slong alen, slong len
 
 void arb_poly_binomial_transform(arb_poly_t b, const arb_poly_t a, slong len, slong prec);
 
+void _arb_poly_graeffe_transform(arb_ptr b, arb_srcptr a, slong len, slong prec);
+
+void arb_poly_graeffe_transform(arb_poly_t b, const arb_poly_t a, slong prec);
+
 /* Special functions */
 
 void _arb_poly_pow_ui_trunc_binexp(arb_ptr res,
@@ -630,6 +640,9 @@ void arb_poly_tan_series(arb_poly_t g, const arb_poly_t h, slong n, slong prec);
 void _arb_poly_sinc_series(arb_ptr g, arb_srcptr h, slong hlen, slong n, slong prec);
 void arb_poly_sinc_series(arb_poly_t g, const arb_poly_t h, slong n, slong prec);
 
+void _arb_poly_sinc_pi_series(arb_ptr g, arb_srcptr h, slong hlen, slong n, slong prec);
+void arb_poly_sinc_pi_series(arb_poly_t g, const arb_poly_t h, slong n, slong prec);
+
 void _arb_poly_compose_series_brent_kung(arb_ptr res, arb_srcptr poly1, slong len1,
                             arb_srcptr poly2, slong len2, slong n, slong prec);
 
@@ -656,6 +669,9 @@ void arb_poly_evaluate2_acb_rectangular(acb_t y, acb_t z, const arb_poly_t f, co
 void _arb_poly_evaluate2_acb(acb_t y, acb_t z, arb_srcptr f, slong len, const acb_t x, slong prec);
 void arb_poly_evaluate2_acb(acb_t y, acb_t z, const arb_poly_t f, const acb_t x, slong prec);
 
+void _arb_poly_lambertw_series(arb_ptr res, arb_srcptr z, slong zlen, int flags, slong len, slong prec);
+void arb_poly_lambertw_series(arb_poly_t res, const arb_poly_t z, int flags, slong len, slong prec);
+
 void _arb_poly_gamma_series(arb_ptr res, arb_srcptr h, slong hlen, slong len, slong prec);
 void arb_poly_gamma_series(arb_poly_t res, const arb_poly_t f, slong n, slong prec);
 
